//<FLAG License>
// Summary:
//   FilterCombobox component
//
// Description:
//   A Combobox that contains the masks with descriptions for file selection.
//   Platformindependent (=> several compromises...)
//   Not very luxurious, but sufficient for JediDBD.
//
// Internal:
//
// Todo:
//   #ToDo1 further tests
//
// Bugs:
//
// History:
// <pre>
//   <b>Version 00.01.00 (Released )</b>
//     04.10.2001 BBU  started
//     14.10.2001 BBU  Initial release
// </pre>
//
//## License:
//##   The contents of this file are subject to the Mozilla Public License
//##   Version 1.1 (the "License"); you may not use this file except in
//##   compliance with the License. You may obtain a copy of the License at
//##   http://www.mozilla.org/MPL/
//##
//##   Software distributed under the License is distributed on an "AS IS"
//##   basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
//##   License for the specific language governing rights and limitations
//##   under the License.
//##
//##   The Original Code is JEDI Database Desktop
//##
//##   Initial Developer of the Original Code is JEDI Database Desktop Project
//##   Portions created by JEDI Database Desktop Project are
//##   Copyright  1997-2001 by JEDI Database Desktop Project.
//##   All Rights Reserved.
//##
//##   For a list of the contributors see the accompanying contributors.txt
//##   file.
//##
//##   You may retrieve the latest version of this file at the JEDI Database
//##   Desktop home page, located at http://jedidbd.sourceforge.net
//##
unit QFilterCombobox;

interface

uses
  Classes, QGraphics, QStdCtrls, QFileListbox;

type
  TFilterComboBox = class(TCustomComboBox)
  private
    FMaskList: TStringList;
    FFilter: string;
    FFileListbox: TFileListBox;
    function GetMask: string;
    procedure SetFileListbox(const Value: TFileListBox);
    procedure SetFilter(const Value: string);
  protected
    procedure Select; override;

    property Style default csDropDownList;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    property Mask: string read GetMask;
  published
    property Filter: string read FFilter write SetFilter;
    property FileListbox: TFileListBox read FFileListbox write SetFileListbox;
    property Width default 177;

    property Anchors;
    property AutoComplete;  //??
    property CharCase;
    property Color default clBase;
    property Constraints;
    property DragMode;
    property DropDownCount;
    //property Duplicates;
    property Enabled;
    property Font;
    //property InsertMode;
    property ItemHeight;
    //property Items;
    property ItemIndex;
    //property MaxItems;
    //property MaxLength;
    property ParentColor;
    property ParentFont;
    property ParentShowHint;
    property PopupMenu;
    property ShowHint default False;
    property Sorted;
    property TabOrder;
    property TabStop;
    property Text;
    property Visible;

    property OnChange;
    property OnClick;
    property OnCloseUp;
    property OnContextPopup;
    property OnDblClick;
    property OnDragDrop;
    property OnDragOver;
    property OnDrawItem;
    property OnDropDown;
    property OnEndDrag;
    property OnEnter;
    property OnExit;
    property OnHighlighted;
    property OnKeyDown;
    property OnKeyPress;
    property OnKeyString;
    property OnKeyUp;
    property OnMeasureItem;
    property OnSelect;
    property OnStartDrag;
  end;

implementation

uses
  SysUtils;

{ TFilterComboBox }

constructor TFilterComboBox.Create(AOwner: TComponent);
begin
  inherited;
  Width := 177;
  FMaskList := TStringList.Create;
  FFilter := '';
  FFileListbox := nil;
  Style := csDropDownList;
end;

destructor TFilterComboBox.Destroy;
begin
  FMaskList.Free;
  inherited;
end;

function TFilterComboBox.GetMask: string;
begin
  if (ItemIndex >= 0) and (ItemIndex < FMaskList.Count) then begin
    Result := FMaskList[ItemIndex];
  end else begin
    Result := '';
  end;
end;

procedure TFilterComboBox.SetFileListbox(const Value: TFileListBox);
begin
  if FFileListBox <> Value then begin
    FFileListbox := Value;
    Select;
  end;
end;

procedure TFilterComboBox.SetFilter(const Value: string);
var
  tmpFilter: String;   // unprocessed part
  DelimPos: integer;   // Position of '|'
  FilterName: string;
  FilterMask: string;
begin
  if FFilter <> Value then begin
    FFilter := Value;
    Items.Clear;
    FMaskList.Clear;

    tmpFilter := FFilter;
    DelimPos := AnsiPos('|', tmpFilter);
    while DelimPos <> 0 do begin
      FilterName := Copy(tmpFilter, 1, DelimPos - 1);
      Delete(tmpFilter, 1, DelimPos);
      DelimPos := AnsiPos('|', tmpFilter);

      if DelimPos > 0 then begin
        FilterMask := Copy(tmpFilter, 1, DelimPos - 1);
        Delete(tmpFilter, 1, DelimPos);
      end else begin
        FilterMask := tmpFilter;
        tmpFilter := '';
      end;
      Items.Add(FilterName);
      FMaskList.Add(FilterMask);
      DelimPos := AnsiPos('|', tmpFilter);
    end;
    if Items.Count > 0 then ItemIndex := 0;
    Select;
  end;
end;

procedure TFilterComboBox.Select;
begin
  if Assigned(FFileListBox) then begin
    FFileListbox.Mask := Mask;
  end;
  inherited;
end;

end.
