{*************************************************************************}
{ TFONTCOMBOBOX component                                                 }
{                                                                         }
{ written by TMS Software                                                 }
{           copyright  2001                                              }
{           Email : info@tmssoftware.com                                  }
{           Web : http://www.tmssoftware.com                              }
{                                                                         }
{ The source code is given as is. The author is not responsible           }
{ for any possible damage done due to the use of this code.               }
{ The component can be freely used in any application. The complete       }
{ source code remains property of the author and may not be distributed,  }
{ published, given or sold in any form as such. No parts of the source    }
{ code can be included in any other component or application without      }
{ written authorization of the author.                                    }
{*************************************************************************}

unit QFontComboBox;

interface

uses
  SysUtils, Types, Classes, QGraphics, QControls, QForms, QDialogs,
  QStdCtrls;

type
  TFontComboBox = class(TCustomComboBox)
  private
    { Private declarations }
    FFocus: Boolean;
    function GetItemIndex: Integer;
    procedure SetItemIndex(const Value: Integer);
  protected
    { Protected declarations }
    function DrawItem(Index: Integer; Rect: TRect;
      State: TOwnerDrawState): Boolean; override;
    procedure DoEnter; override;
    procedure DoExit; override;
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    procedure Loaded; override;

  published
    { Published declarations }
    property Anchors;
    property Color;
    property Constraints;
    property DragMode;
    property DropDownCount;
    property Enabled;
    property Font;
    property ItemHeight;
    property ItemIndex: Integer read GetItemIndex write SetItemIndex;
    property ParentColor;
    property ParentFont;
    property ParentShowHint;
    property ShowHint;
    property TabOrder;
    property Visible;
    property OnChange;
    property OnClick;
    property OnCloseUp;
    property OnContextPopup;
    property OnDblClick;
    property OnDragDrop;
    property OnDropDown;
    property OnEndDrag;
    property OnEnter;
    property OnExit;
    property OnHighLighted;
    property OnKeyDown;
    property OnKeyPress;
    property OnKeyString;
    property OnKeyUp;
    property OnMeasureItem;
    property OnSelect;
    property OnStartDrag;
  end;


implementation


{ TColorComboBox }

constructor TFontComboBox.Create(AOwner: TComponent);
var
  i: Integer;
begin
  inherited;
  Style := csOwnerDrawFixed;
  for i := 1 to Screen.Fonts.Count do
   Items.Add(Screen.Fonts.Strings[i - 1]);
  ItemIndex := 0;
end;

procedure TFontComboBox.DoEnter;
begin
  inherited;
  FFocus := True;
end;

procedure TFontComboBox.DoExit;
begin
  inherited;
  FFocus := False;
end;

function TFontComboBox.DrawItem(Index: Integer; Rect: TRect;
  State: TOwnerDrawState): Boolean;
var
  Nm : string;
begin
  inherited DrawItem(Index,Rect,State);

  if (Index < Items.Count) and (Index >= 0) then
    Nm := Items[Index]
  else
    Nm := '???';
  

  if (odFocused in State) or
     (FFocus and (odSelected in State)) then
  begin
    Canvas.Font.Color := clHighLightText;
    Canvas.Brush.Color := clHighLight;
  end
  else
  begin
    Canvas.Font.Color := Font.Color;
    Canvas.Brush.Color := clWhite;
  end;

  Canvas.Pen.Color := Canvas.Brush.Color;
  Canvas.Rectangle(Rect.Left, Rect.Top, Rect.Right, Rect.Bottom);
  Inc(Rect.Left);

  Canvas.Font.Name := Nm;

  Canvas.TextOut(Rect.Left , Rect.Top, Nm);
  Result := True;
end;

function TFontComboBox.GetItemIndex: Integer;
begin
  Result := inherited ItemIndex;
end;

procedure TFontComboBox.Loaded;
begin
  inherited;
end;

procedure TFontComboBox.SetItemIndex(const Value: Integer);
begin
  if Value < Items.Count then
  begin
    inherited ItemIndex := Value;
    Invalidate;
  end;
end;

end.
